""" Raw event object structures for api. """
from dataclasses import dataclass
from typing import List, Optional

from luna3.events.http_objs import BaseClass, Location
from luna3.handlers.http_objs import (
    AggregateEstimations,
    RawBodyAttributes,
    RawDetections,
    RawFace,
    RawFaceAttributes,
    RawMatch,
)


@dataclass
class ApiRawEvent(BaseClass):
    """
    Raw event class for api.

    Attributes:
        createTime: event create time
        endTime: event end time
        detections: list of body & face related detections
        faceAttributes: extracted face attributes from samples
        bodyAttributes: extracted body attributes from samples
        externalId: external id
        face: created face
        location: location
        matches: list with match result for the event
        source: source
        streamId: stream id
        tags: list of tags
        trackId: track id
        userData: user data
        aggregateEstimations: aggregate estimations
        meta: user-defined event metadata
    """

    detections: Optional[List[RawDetections]] = None
    location: Optional[Location] = None
    faceAttributes: Optional[RawFaceAttributes] = None
    bodyAttributes: Optional[RawBodyAttributes] = None
    externalId: Optional[str] = None
    face: Optional[RawFace] = None
    matches: Optional[List[RawMatch]] = None
    source: Optional[str] = None
    streamId: Optional[str] = None
    tags: Optional[List[str]] = None
    trackId: Optional[str] = None
    userData: Optional[str] = None
    createTime: Optional[str] = None
    endTime: Optional[str] = None
    aggregateEstimations: Optional[AggregateEstimations] = None
    meta: Optional[dict] = None
